@@ -23,7 +23,7 @@ absen = [
     "**Hadir kak maap telat** 🥺",
 ]
 
-def hacking(client, Client, message: Message):
+def hacking():
     hacking = message.reply_text
 
 blockyou = 1447438514
